Skip to contents

High-level function calling infer_barcode and compare_seqs on every sample. Parallel processing possible with cores > 1. Custom parallel processing frameworks can be plugged in by providing parallel_lapply_fn.

Usage

do_infer_all_barcodes(
  seq_tab,
  dada_err,
  aln_out = NULL,
  tmp_dir = NULL,
  parallel_lapply_fn = NULL,
  ...,
  cores = NULL
)

Arguments

seq_tab

Sequence metadata table returned by do_trim_demux or do_demux

dada_err

Result of dada_learn_errors

aln_out

Optional output directory for BAM alignments (none saved if NULL)

tmp_dir

Optional temporary directory (default: user-specific temporary directory, see set_global_opts)

parallel_lapply_fn

Optional lapply-like function

...

passed to infer_barcode

cores

Number of cores to use (default: 1, unless getOption('DadaNanoBC.cores') is defined, or the DadaNanoBC_cores environment variable is set)

Value

Input table (seq_tab) with a new column clustering, which is a list of data frames as returned by infer_barcode